BendPoint class
One control point of a bend/whammy curve.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- position ↔ int
-
Horizontal position along the bend (0–BendEffect.maxPosition).
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value ↔ int
-
Vertical value (pitch offset) at this point.
getter/setter pair
- vibrato ↔ bool
-
Whether vibrato is applied at this point.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited