ChordExtension class

Chord extension (ninth, eleventh, thirteenth). Lenient.

Constructors

ChordExtension(int value)
Wraps a raw value.
const

Properties

hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Raw on-disk extension tag.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override

Constants

eleventh → const ChordExtension
Eleventh.
ninth → const ChordExtension
Ninth.
none → const ChordExtension
No extension.
thirteenth → const ChordExtension
Thirteenth.