TrackSettings class

Notation/diagram display options for a track.

Constructors

TrackSettings()

Properties

autoBrush bool
Auto brush (strum).
getter/setter pair
autoLetRing bool
Auto let-ring.
getter/setter pair
diagramList bool
Show the chord-diagram list.
getter/setter pair
diagramsAreBelow bool
Place chord diagrams below the staff.
getter/setter pair
diagramsInScore bool
Show diagrams inline in the score.
getter/setter pair
extendRhythmic bool
Extend rhythmic durations.
getter/setter pair
forceChannels bool
Force per-beat channels.
getter/setter pair
forceHorizontal bool
Force horizontal layout.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
notation bool
Show standard notation staff.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showRhythm bool
Show rhythm slashes.
getter/setter pair
tablature bool
Show tablature staff.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited