TripletFeel enum

Swing/triplet feel applied to a measure.

Inheritance
Available extensions

Values

none → const TripletFeel

Straight (no swing).

const TripletFeel(0)
eighth → const TripletFeel

Eighth-note swing.

const TripletFeel(1)
sixteenth → const TripletFeel

Sixteenth-note swing.

const TripletFeel(2)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value int
Raw on-disk value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromValue(int v) TripletFeel
Maps a raw v to a member, throwing GpException if unknown.

Constants

values → const List<TripletFeel>
A constant List of the values in this enum, in order of their declaration.